# Zaber Motion Library

Zaber Motion Library is a multi-platform library used to operate Zaber devices.

External documentation: [https://www.zaber.com/software/docs/motion-library/](https://www.zaber.com/software/docs/motion-library/)
